unit Nova;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls,
  novaOptions,
  novapiLib90_TLB;

procedure AddProfileOptions(pNova : INovaPdfOptions90);
procedure AddAdvancedOptions(pNova : INovaPdfOptions90);
procedure AddWatermarkImage(pNova : INovaPdfOptions90);
procedure AddWatermarkText(pNova : INovaPdfOptions90);
procedure AddBookmarksDefinitions(pNova : INovaPdfOptions90);
procedure AddDocumentInformation(pNova : INovaPdfOptions90);
procedure AddDocumentXMPMetadata(pNova : INovaPdfOptions90);
procedure AddViewerOptions(pNova : INovaPdfOptions90);
procedure AddSecurity(pNova : INovaPdfOptions90);
procedure AddLinksOptions(pNova : INovaPdfOptions90);
procedure AddSaveOptions(pNova : INovaPdfOptions90);
procedure AddEmbedFontsOptions(pNova : INovaPdfOptions90);
procedure AddGraphicsOptions(pNova : INovaPdfOptions90);
procedure AddOverlayOptions(pNova : INovaPdfOptions90);
procedure AddSignatureOptions(pNova : INovaPdfOptions90);
procedure AddPageContentOptions(pNova : INovaPdfOptions90);
procedure AddActionsOptions(pNova : INovaPdfOptions90);

implementation

//------------------------------------------------------------------------------------------//
//-------------------------------------  PROFILE  -----------------------------------------//
//------------------------------------------------------------------------------------------//
procedure AddProfileOptions(pNova : INovaPdfOptions90);
begin
	//profile author
	pNova.SetOptionString2(NOVAPDF_PROFILE_AUTHOR, 'Hello World application');
	//profile description
	pNova.SetOptionString2(NOVAPDF_PROFILE_DESCRIPTION, 'Hello World application settings');
	//PDF version
	pNova.SetOptionLong(NOVAPDF_PDF_VERSION, PDF_VERSION_17);
	//generate PDFA compliant docs
	pNova.SetOptionBool(NOVAPDF_PDFA, 0);
	//choose between PDFA/1a or PDFA/1b standards
	pNova.SetOptionLong(NOVAPDF_PDFA_VERSION, PDFA_1A);
	//generate linearized docs
	pNova.SetOptionBool(NOVAPDF_PDF_LINEARIZE, 0);
end;

//------------------------------------------------------------------------------------------//
//-------------------------------------  ADVANCED  -----------------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddAdvancedOptions(pNova : INovaPdfOptions90);
begin
	//advanced options
	pNova.SetOptionBool(NOVAPDF_ADV_OPTIMIZE_TEXT, 1);
	pNova.SetOptionBool(NOVAPDF_ADV_OPTIMIZE_IMAGE, 0);
	pNova.SetOptionBool(NOVAPDF_ADV_SILENT_PRINT, 0);
	pNova.SetOptionBool(NOVAPDF_ADV_CORRECT_FILLCOLOR, 0);
	pNova.SetOptionBool(NOVAPDF_ADV_CORRECT_LINEWIDTH, 0);
	pNova.SetOptionBool(NOVAPDF_ADV_IGNORE_EMPTY_PAGES, 0);
	pNova.SetOptionBool(NOVAPDF_ADV_VERIFY_FILE, 0);
	pNova.SetOptionBool(NOVAPDF_ADV_COPIES_ADD_PAGE, 0);
	pNova.SetOptionBool(NOVAPDF_ADV_COPIES_ONLY_ODD, 0);
end;
//------------------------------------------------------------------------------------------//
//-------------------------------------  WATERMARK IMAGE -----------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddWatermarkImage(pNova : INovaPdfOptions90);
var
  strWtmImageId : WideString;
  strLayoutImageId : WideString;
begin
	pNova.AddWatermarkImage2(strWtmImageId, strLayoutImageId);
	//metadata
	pNova.SetWatermarkImageOptionString2(strWtmImageId, NOVAPDF_WTM_IMG_NAME, 'WtmImage');
	pNova.SetWatermarkImageOptionString2(strWtmImageId, NOVAPDF_WTM_IMG_AUTHOR, 'Hello World application');
	pNova.SetWatermarkImageOptionString2(strWtmImageId, NOVAPDF_WTM_IMG_DESCRIPTION, 'image watermark');
	//watermark image file
	pNova.SetWatermarkImageOptionString2(strWtmImageId, NOVAPDF_WTM_IMG_IMAGE_FILE_NAME, 'copy.png');
	pNova.SetWatermarkImageOptionLong2(strWtmImageId, NOVAPDF_WTM_IMG_IMAGE_LOCATION, LOCATION_TYPE_LOCAL);
	pNova.SetWatermarkImageOptionString2(strWtmImageId, NOVAPDF_WTM_IMG_IMAGE_USER_NAME, '');
	pNova.SetWatermarkImageOptionEncryptedString2(strWtmImageId, NOVAPDF_WTM_IMG_IMAGE_USER_PASSWORD, '');
	//use transparency
	pNova.SetWatermarkImageOptionBool2(strWtmImageId, NOVAPDF_WTM_IMG_IMAGE_TRANSPARENCY, 1);
	pNova.SetWatermarkImageOptionLong2(strWtmImageId, NOVAPDF_WTM_IMG_IMAGE_TRANSP_COLOR, RGB(0,0,0));
	//opacity
	pNova.SetWatermarkImageOptionLong2(strWtmImageId, NOVAPDF_WTM_IMG_IMAGE_OPACITY, 50);
	//color variation
	pNova.SetWatermarkImageOptionLong2(strWtmImageId, NOVAPDF_WTM_IMG_COLOR_VARIATION, 0);
	//visibility
	pNova.SetWatermarkImageOptionBool2(strWtmImageId, NOVAPDF_WTM_IMG_VISIBILITY_VIEW, 1);
	pNova.SetWatermarkImageOptionBool2(strWtmImageId, NOVAPDF_WTM_IMG_VISIBILITY_PRINT, 1);
	pNova.SetWatermarkImageOptionBool2(strWtmImageId, NOVAPDF_WTM_IMG_VISIBILITY_EXPORT, 1);

	//LAYOUT
	//metadata
	pNova.SetLayoutOptionString2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_NAME, 'WtmImage Layout');
	pNova.SetLayoutOptionString2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_AUTHOR, 'Hello World application');
	pNova.SetLayoutOptionString2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_DESCRIPTION, 'image watermark position on page');
	//anchors
	//offset is set as percentage or thousands of mm
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_LEFTANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_LEFTANCHOR_OFFSET, 10);
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_LEFTANCHOR_USE_PERCENT, 1);

	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_RIGHTANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_RIGHTANCHOR_OFFSET, 50000);
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_RIGHTANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_TOPANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_TOPANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_TOPANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_BOTTOMANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_VERTANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_VERTLANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_VERTANCHOR_USE_PERCENT, 1);

	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_HORIZANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_HORIZANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_HORIZANCHOR_USE_PERCENT, 0);

	//aspect ratio
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_USE_ASPECT_RATIO, 1);
	//allow stretch with anchors when print on a different page size or layout
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_ALLOW_STRETCH, 0);

	//Width / Height
	//thousands of mm
	pNova.SetLayoutOptionFloat2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_OBJECT_WIDTH, 100000);
	pNova.SetLayoutOptionFloat2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_OBJECT_HEIGHT, 100000);

	//Rotation
	//radians
	pNova.SetLayoutOptionFloat2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_ROTATION, 0);

	//ZIndex (multiple of 5) - objects with higher ZIndex will be above the ones with smaller ZIndex
	pNova.SetLayoutOptionLong2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_ZINDEX, 15);

	//Border
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_USE_BORDER, 1);
	pNova.SetLayoutOptionLong2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_BORDER_POSITION, 0);
	pNova.SetLayoutOptionLong2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_BORDER_WIDTH, 2000);
	pNova.SetLayoutOptionLong2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_BORDER_STYLE, BORDER_STYLE_SOLID);
	pNova.SetLayoutOptionLong2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_BORDER_COLOR, RGB(255,120,200));
	
	//pages
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_FIRSTPAGE, 0);
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_LASTPAGE, 0);
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_ODDPAGE, 0);
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_EVENPAGE, 0);
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_ALLPAGE, 1);
	pNova.SetLayoutOptionBool2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_PAGES, 0);
	pNova.SetLayoutOptionString2(strWtmImageId, strLayoutImageId, NOVAPDF_LAYOUT_PAGERANGE, '1-2');
	
end;

//------------------------------------------------------------------------------------------//
//-------------------------------------  WATERMARK TEXT ------------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddWatermarkText(pNova : INovaPdfOptions90);
var
  strWtmTextId : WideString;
  strLayoutTextId : WideString;
begin
	pNova.AddWatermarkText2(strWtmTextId, strLayoutTextId);
	//metadata
	pNova.SetWatermarkTextOptionString2(strWtmTextId, NOVAPDF_WTM_TXT_NAME, 'WtmText');
	pNova.SetWatermarkTextOptionString2(strWtmTextId, NOVAPDF_WTM_TXT_AUTHOR, 'Hello World application');
	pNova.SetWatermarkTextOptionString2(strWtmTextId, NOVAPDF_WTM_TXT_DESCRIPTION, 'text image');
	//watermark text
	pNova.SetWatermarkTextOptionString2(strWtmTextId, NOVAPDF_WTM_TXT_WATERMARK_TEXT, 'Watermark');
	//font
	pNova.SetWatermarkTextOptionString2(strWtmTextId, NOVAPDF_WTM_TXT_FONT_NAME, 'Arial');
	pNova.SetWatermarkTextOptionLong2(strWtmTextId, NOVAPDF_WTM_TXT_FONT_TYPE, NOVA_FONTTYPE_TRUETYPE);
	pNova.SetWatermarkTextOptionLong2(strWtmTextId, NOVAPDF_WTM_TXT_FONT_SIZE, 74);
	//font style
	pNova.SetWatermarkTextOptionBool2(strWtmTextId, NOVAPDF_WTM_TXT_FONT_BOLD, 1);
	pNova.SetWatermarkTextOptionBool2(strWtmTextId, NOVAPDF_WTM_TXT_FONT_ITALIC, 1);
	pNova.SetWatermarkTextOptionBool2(strWtmTextId, NOVAPDF_WTM_TXT_FONT_OUTLINE, 0);
	pNova.SetWatermarkTextOptionBool2(strWtmTextId, NOVAPDF_WTM_TXT_FONT_UNDERLINE, 0);
	//font color
	pNova.SetWatermarkTextOptionLong2(strWtmTextId, NOVAPDF_WTM_TXT_FONT_COLOR, RGB(32,178,169));
	//opacity
	pNova.SetWatermarkTextOptionLong2(strWtmTextId, NOVAPDF_WTM_TXT_OPACITY, 50);
	//visibility
	pNova.SetWatermarkTextOptionBool2(strWtmTextId, NOVAPDF_WTM_TXT_VISIBILITY_VIEW, 1);
	pNova.SetWatermarkTextOptionBool2(strWtmTextId, NOVAPDF_WTM_TXT_VISIBILITY_PRINT, 1);
	pNova.SetWatermarkTextOptionBool2(strWtmTextId, NOVAPDF_WTM_TXT_VISIBILITY_EXPORT, 1);

	//LAYOUT
	//metadata
	pNova.SetLayoutOptionString2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_NAME, 'WtmText Layout');
	pNova.SetLayoutOptionString2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_AUTHOR, 'Hello World application');
	pNova.SetLayoutOptionString2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_DESCRIPTION, 'text watermark position on page');

	//anchors
	//offset is set as percentage or thousands of mm
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_LEFTANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_LEFTANCHOR_OFFSET, 10);
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_LEFTANCHOR_USE_PERCENT, 1);

	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_RIGHTANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_RIGHTANCHOR_OFFSET, 20000);
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_RIGHTANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_TOPANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_TOPANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_TOPANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_BOTTOMANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_VERTANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_VERTLANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_VERTANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_HORIZANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_HORIZANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_HORIZANCHOR_USE_PERCENT, 0);

	//aspect ratio
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_USE_ASPECT_RATIO, 1);
	//allow stretch with anchors when print on a different page size or layout
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_ALLOW_STRETCH, 0);

	//ZIndex (multiple of 5) - objects with higher ZIndex will be above the ones with smaller ZIndex
	pNova.SetLayoutOptionLong2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_ZINDEX, 20);

	//Rotation (radians)
	pNova.SetLayoutOptionFloat2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_ROTATION, 0.94);

	//Border
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_USE_BORDER, 0);
	pNova.SetLayoutOptionLong2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_BORDER_POSITION, 0);
	pNova.SetLayoutOptionLong2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_BORDER_WIDTH, 2000);
	pNova.SetLayoutOptionLong2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_BORDER_STYLE, BORDER_STYLE_SOLID);
	pNova.SetLayoutOptionLong2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_BORDER_COLOR, RGB(255,120,200));

	//pages
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_FIRSTPAGE, 0);
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_LASTPAGE, 0);
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_ODDPAGE, 0);
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_EVENPAGE, 0);
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_ALLPAGE, 1);
	pNova.SetLayoutOptionBool2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_PAGES, 0);
	pNova.SetLayoutOptionString2(strWtmTextId, strLayoutTextId, NOVAPDF_LAYOUT_PAGERANGE, '1-2');
end;

//------------------------------------------------------------------------------------------//
//-------------------------------------  BOOKMARKS ----------------------------------------//
//------------------------------------------------------------------------------------------//
procedure AddBookmarksDefinitions(pNova : INovaPdfOptions90);
var
  nDefinition, i, nCount : Smallint;
begin
  //novaPDF driver will serach the text in the printed document, and if some text matches a bookmark definition
  //(for font, style, ssize, color) a bookmark with this text will be added in the pdf file.

  //first enable bookmarks - mandatory
	//Enable bookmarks
	pNova.SetOptionBool(NOVAPDF_BMARK_EN_AUTO_DET_BMARKS, 1);

	//novaPDF driver will serach the text in the printed document, and if some text matches a bookmark definition
	//(for font, style, ssize, color) a bookmark with this text will be added in the pdf file.

	//if default profile contains some definitions, delete them
	pNova.GetBookmarkDefinitionCount(nCount);
	for i := nCount - 1 downto 0  do
	begin
		pNova.DeleteBookmarkDefinition(i);
	end;

	//add new definition
	pNova.AddBookmarkDefinition2(1, //Heading index
		1, //definition is enabled
		1, //check font name in the printed text
		'Batang', //font name
		NOVA_FONTTYPE_TRUETYPE, //font type
		1, //check font style in the printed text
		1,  //bold font
		0,  //italic font
		1, //check font size in the printed text
		22, //font size
		0.4, //font size aproximation
		0, //check font color in the printed text
		RGB(255, 0, 0), //font color
		1, //display bookmark as bold in pdf
		0, //display bookmark as italic in pdf,
		RGB(0, 0, 255),  //display bookmark with this color in pdf
		nDefinition //definition number
		);
		
    //Change general bookmarks settings
    pNova.SetOptionBool(NOVAPDF_BMK_ALLOW_MULTILINE, 1);
    pNova.SetOptionBool(NOVAPDF_BMK_MATCH_ALL_LEVELS, 1);
    pNova.SetOptionLong(NOVAPDF_BMK_USE_LEVELS, 1);
    pNova.SetOptionLong(NOVAPDF_BMK_OPEN_TO_LEVEL, 1);

    //Add root bookmark
    pNova.SetOptionBool(NOVAPDF_BMK_ROOT_ENABLED, 1);
    pNova.SetOptionString2(NOVAPDF_BMK_ROOT_NAME, 'Document - [T]');
    pNova.SetOptionBool(NOVAPDF_BMK_ROOT_BOLD, 0);
    pNova.SetOptionBool(NOVAPDF_BMK_ROOT_ITALIC, 1);
    pNova.SetOptionLong(NOVAPDF_BMK_ROOT_COLOR, 0);

end;

//------------------------------------------------------------------------------------------//
//--------------------------------  DOCUMENT INFORMATION  ----------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddDocumentInformation(pNova : INovaPdfOptions90);
begin
	pNova.SetOptionBool(NOVAPDF_INFO_ENABLE, 1);
	//show a dialog before printing each document to enter doc info
	pNova.SetOptionBool(NOVAPDF_SHOW_DOCINFO_DLG, 0);
	//pdf document information
	//pdf document information
	pNova.SetOptionString2(NOVAPDF_DOCINFO_TITLE, 'My Doc Title');
	pNova.SetOptionString2(NOVAPDF_DOCINFO_SUBJECT, 'My Doc Subject');
	pNova.SetOptionString2(NOVAPDF_DOCINFO_AUTHOR, 'My Doc Author');
	pNova.SetOptionString2(NOVAPDF_DOCINFO_CREATOR, 'My Doc Creator');
	pNova.SetOptionString2(NOVAPDF_DOCINFO_KEYWORDS, 'keyword1, keyword2,...');
end;

//------------------------------------------------------------------------------------------//
//--------------------------------  DOCUMENT METADATA --------------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddDocumentXMPMetadata(pNova : INovaPdfOptions90);
begin
	pNova.SetOptionBool(NOVAPDF_ADD_XMP_METADATA, 1);
	//copyright information
	pNova.SetOptionString2(NOVAPDF_COPYRIGHT_TEXT, 'My Doc Copyright Text');
	pNova.SetOptionString2(NOVAPDF_COPYRIGHT_URL, 'My Doc Copyright URL');
	pNova.SetOptionLong(NOVAPDF_COPYRIGHT_TYPE, COPYRIGHT_TYPE_COPYRIGHTED);
end;

//------------------------------------------------------------------------------------------//
//--------------------------------  VIEWER OPTIONS  ----------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddViewerOptions(pNova : INovaPdfOptions90);
begin
	pNova.SetOptionBool(NOVAPDF_INFO_VIEWER_ENABLE, 1);

	pNova.SetOptionBool(NOVAPDF_VIEWOP_HIDE_TOOLBARS, 1);
	pNova.SetOptionBool(NOVAPDF_VIEWOP_SHOW_DOCTITLE, 1);
	pNova.SetOptionBool(NOVAPDF_VIEWOP_HIDE_MENUBAR, 1);
	pNova.SetOptionBool(NOVAPDF_VIEWOP_RESIZE_WINDOW, 1);
	pNova.SetOptionBool(NOVAPDF_VIEWOP_HIDE_USER, 1);

	pNova.SetOptionLong(NOVAPDF_VIEWOP_TRANSITION_TYPE, TRANSITION_TYPE_REPLACE);
	pNova.SetOptionLong(NOVAPDF_VIEWOP_TRANSITION_DIRECTION, TRANSITION_DIR_VERT);
	pNova.SetOptionLong(NOVAPDF_VIEWOP_TRANSITION_DURATION, 2);
	pNova.SetOptionLong(NOVAPDF_VIEWOP_PAGE_DURATION, 2);

	pNova.SetOptionBool(NOVAPDF_VIEWOP_USE_START_PAGE, 1);
	pNova.SetOptionLong(NOVAPDF_VIEWOP_START_PAGE, 1);

	pNova.SetOptionLong(NOVAPDF_VIEWOP_ZOOM, PAGE_MAGN_VIEWERDEFAULT);
	pNova.SetOptionLong(NOVAPDF_VIEWOP_PAGE_LAYOUT, PAGE_LAY_VIEWERDEF);
	pNova.SetOptionLong(NOVAPDF_VIEWOP_PAGE_MODE, PAGE_MODE_VIEWERDEFAULT);
	pNova.SetOptionLong(NOVAPDF_VIEWOP_PAGE_SCALING, PAGE_SCALE_APPDEFAULT);
	pNova.SetOptionLong(NOVAPDF_VIEWOP_FULLSCREEN, FULLSCREEN_VIEWERDEF);

end;

//------------------------------------------------------------------------------------------//
//----------------------------------------  SECURITY  --------------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddSecurity(pNova : INovaPdfOptions90);
begin
	//first enable security - mandatory
	pNova.SetOptionBool(NOVAPDF_SEC_ENABLE, 1);
	//if a dialog should be shown before printing wach document, to change password
	pNova.SetOptionBool(NOVAPDF_SHOW_SECURITY_DLG, 0);
	//level
	pNova.SetOptionLong(NOVAPDF_SECURITY_LEVEL, SECURITY_128BITS);
	//then set security flags: 1 if it is allowed, 0 if not
	//print document
	pNova.SetOptionBool(NOVAPDF_SECURITY_FLAG_PRINTDOC, 1);
	//modify document content
	pNova.SetOptionBool(NOVAPDF_SECURITY_FLAG_MODIFYDOC, 1);
	//extract text and grapics
	pNova.SetOptionBool(NOVAPDF_SECURITY_FLAG_EXTRACTTEXT, 1);
	//modify annotations, fill forms
	pNova.SetOptionBool(NOVAPDF_SECURITY_FLAG_MODIFYANNOTATION, 1);
	//advanced fill forms
	pNova.SetOptionBool(NOVAPDF_SECURITY_FLAG_ADVANCEDFILL, 0);
	//advanced extract text and graphics
	pNova.SetOptionBool(NOVAPDF_SECURITY_FLAG_ADVANCEDEXTRACT, 1);
	//assemble the document
	pNova.SetOptionBool(NOVAPDF_SECURITY_FLAG_ASSEMBLEDOC, 1);
	//print at high resolution
	pNova.SetOptionBool(NOVAPDF_SECURITY_FLAG_PRINTHIGHRES, 1);

	//passwords are set as encrypted strings (owner password is mandatory, user password is optional)
	//user password for opening the PDF
	pNova.SetOptionEncryptedString2(NOVAPDF_SECURITY_USER_PASSWORD, 'my user password');
	//owner password for changing PDF security
	pNova.SetOptionEncryptedString2(NOVAPDF_SECURITY_OWNER_PASSWORD, 'my owner password');
end;


//------------------------------------------------------------------------------------------//
//--------------------------------------  DETECT LINKS  ------------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddLinksOptions(pNova : INovaPdfOptions90);
begin
	// detect link / URL options
	//first enable links option - mandatory
	pNova.SetOptionBool(NOVAPDF_URL_ANALIZE, 1);
	//flag to detect or not file links
	pNova.SetOptionBool(NOVAPDF_URL_DETECT_FILES, 1);
	//when detecting file links, check if the file actually exists (1-check, 0-do not check)
	pNova.SetOptionBool(NOVAPDF_URL_CHECK_FILE_EXISTS, 1);
	//how to show the links in the pdf file
	pNova.SetOptionBool(NOVAPDF_URL_UNDERLINE, 1);
	//set links color blue
	pNova.SetOptionBool(NOVAPDF_URL_OVERWRITE_COLOR, 1);
	pNova.SetOptionLong(NOVAPDF_URL_COLOR, RGB(0,0,255));
end;


//------------------------------------------------------------------------------------------//
//--------------------------------------  FONTS OPTIONS  -----------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddEmbedFontsOptions(pNova : INovaPdfOptions90);
begin
	//embed all used fionts in the pdf file
	pNova.SetOptionBool(NOVAPDF_FONTS_EMBED_ALL_USED_FONTS, 1);
	//embed only a subset of the fonts (only the characters that are used in the document)
	//embed all fonts has to be set too, otherwise fonts will not be embedded at all
	pNova.SetOptionBool(NOVAPDF_FONTS_EMBED_SUBSETS, 1);
	//some fonts cannot be embedded because their license does not allow the font to be embedded
	//but with the next option you can force to embed licensed fonts
	pNova.SetOptionBool(NOVAPDF_FONTS_FORCE_EMBED_PROTECTED, 1);
	//if we have some specific fonts that we wish to add to embed/ not emebed lists
	pNova.ClearFontOptions();
	pNova.SetFontOption2('Arial', 1, 0);
	pNova.SetFontOption2('Verdana', 0, 1);
	pNova.SetFontOption2('Courier', 0, 1);
end;

//------------------------------------------------------------------------------------------//
//------------------------------------  GRAPHICS OPTIONS  ----------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddGraphicsOptions(pNova : INovaPdfOptions90);
begin
	//enable image compression
	pNova.SetOptionBool(NOVAPDF_COMPRESS_ENABLE, 1);
	// compression settings for high color images - flag, method, level
	pNova.SetOptionBool(NOVAPDF_COMPRESS_HIGH_COLOR, 1);
	pNova.SetOptionLong(NOVAPDF_COMPRESS_HIGH_COLOR_TYPE, COMPRESS_METHOD_JPEG);
	pNova.SetOptionLong(NOVAPDF_COMPRESS_HIGH_COLOR_LEVEL, 77);
	// compression settings for indexed images - flag, method, level
	pNova.SetOptionBool(NOVAPDF_COMPRESS_INDEXED, 1);
	pNova.SetOptionLong(NOVAPDF_COMPRESS_INDEXED_TYPE, COMPRESS_METHOD_ZIP);
	pNova.SetOptionLong(NOVAPDF_COMPRESS_INDEXED_LEVEL, 5);
	// compression settings for monochrome images - flag, method, level
	pNova.SetOptionBool(NOVAPDF_COMPRESS_MONOCHROM, 1);
	pNova.SetOptionLong(NOVAPDF_COMPRESS_MONOCHROM_TYPE, COMPRESS_METHOD_ZIP);
	pNova.SetOptionLong(NOVAPDF_COMPRESS_MONOCHROM_LEVEL, 5);
	// compression settings for text and graphics - flag, method, level
	pNova.SetOptionBool(NOVAPDF_COMPRESS_TEXT_GRAPHICS, 1);
	pNova.SetOptionLong(NOVAPDF_COMPRESS_TEXT_GRAPHICS_TYPE, COMPRESS_METHOD_ZIP);
	pNova.SetOptionLong(NOVAPDF_COMPRESS_TEXT_GRAPHICS_LEVEL, 5);

	//enable downsample
	pNova.SetOptionBool(NOVAPDF_GR_DOWNSMPL_ENABLE, 1);
	//downsample high color images - flag, dpi, method
	pNova.SetOptionBool(NOVAPDF_DOWNSAMPLE_HIGH_COLOR, 1);
	pNova.SetOptionLong(NOVAPDF_DOWNSAMPLE_RES_HIGH_COLOR, 96);
	pNova.SetOptionLong(NOVAPDF_DOWNSAMPLE_TYPE_HIGH_COLOR, DOWNSAMPLE_FILTER_BICUBIC);
	//downsample indexed images - flag, dpi, method
	pNova.SetOptionBool(NOVAPDF_DOWNSAMPLE_INDEXED, 1);
	pNova.SetOptionLong(NOVAPDF_DOWNSAMPLE_RES_INDEXED, 96);
	pNova.SetOptionLong(NOVAPDF_DOWNSAMPLE_TYPE_INDEXED, DOWNSAMPLE_FILTER_BICUBIC);
	//downsample monochrome images - flag, dpi, method
	pNova.SetOptionBool(NOVAPDF_DOWNSAMPLE_MONOCHROM, 1);
	pNova.SetOptionLong(NOVAPDF_DOWNSAMPLE_RES_MONOCHROM, 96);
	pNova.SetOptionLong(NOVAPDF_DOWNSAMPLE_TYPE_MONOCHROM, DOWNSAMPLE_FILTER_BICUBIC);

	//enable image convertion
	pNova.SetOptionBool(NOVAPDF_GR_CONVERT_ENABLE, 1);
	//convert high color images - flag, type
	pNova.SetOptionBool(NOVAPDF_IMAGE_CONVERT_HIGH_COLOR, 1);
	pNova.SetOptionLong(NOVAPDF_IMAGE_CONVERT_TYPE_HIGH_COLOR, CONVERT_GRAYSCALE);
	//if convert to monochrome, set trashold color and dithering method
	pNova.SetOptionLong(NOVAPDF_IMAGE_CONVERT_TRESH_HIGH_COLOR, 128);
	//use or no dithering
	pNova.SetOptionBool(NOVAPDF_IMAGE_DITHER_HIGH_COLOR, 1);
	pNova.SetOptionLong(NOVAPDF_IMAGE_DITHER_TYPE_HIGH_COLOR, DITHER_BAYER4);
	//convert indexed images - flag, type
	pNova.SetOptionBool(NOVAPDF_IMAGE_CONVERT_INDEXED, 1);
	pNova.SetOptionLong(NOVAPDF_IMAGE_CONVERT_TYPE_INDEXED, CONVERT_GRAYSCALE);
	//if convert to monochrome, set trashold color and dithering method
	pNova.SetOptionLong(NOVAPDF_IMAGE_CONVERT_TRESH_INDEXED, 128);
	//use or no dithering
	pNova.SetOptionBool(NOVAPDF_IMAGE_DITHER_INDEXED, 1);
	pNova.SetOptionLong(NOVAPDF_IMAGE_DITHER_TYPE_INDEXED, DITHER_BAYER4);
	//convert text and graphics colors - flag, type
	pNova.SetOptionBool(NOVAPDF_IMAGE_CONVERT_TEXTANDGR, 1);
	pNova.SetOptionLong(NOVAPDF_IMAGE_CONVERT_TYPE_TEXTANDGR, CONVERT_GRAYSCALE);
	//if convert to monochrome, set trashold color
	pNova.SetOptionLong(NOVAPDF_IMAGE_CONVERT_TRESH_TEXTANDGR, 128);
end;

//------------------------------------------------------------------------------------------//
//-------------------------------------  OVERLAY OPTIONS  ----------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddOverlayOptions(pNova : INovaPdfOptions90);
var
	strOverlayId, strLayoutId : WideString;
begin
	//set the pdf file you wish to overlay with (with full path)
	pNova.SetOptionLong(NOVAPDF_OVERLAY_FILE_LOCATION, LOCATION_TYPE_LOCAL);
	pNova.SetOptionString2(NOVAPDF_OVERLAY_FILE, 'letterhead-template.pdf');
	//if the file is password protected, enter the password here
	pNova.SetOptionEncryptedString2(NOVAPDF_OVERLAY_FILE_PASSWORD, '');
	//if the overlay file is on a network path, set network user name and password to access this path
	pNova.SetOptionString2(NOVAPDF_OVERLAY_USER_NAME, '');
	pNova.SetOptionEncryptedString2(NOVAPDF_OVERLAY_USER_PASSWORD, '');

	//repeat overlay option
	pNova.SetOptionLong(NOVAPDF_OVERLAY_REPEAT_TYPE, OVERLAY_REPEAT_ALL);
	//opacity
	pNova.SetOptionLong(NOVAPDF_OVERLAY_OPACITY, 50);

	//LAYOUT
	pNova.GetOverlay2(strOverlayId, strLayoutId);

	//metadata
	pNova.SetLayoutOptionString2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_NAME, 'Overlay Layout');
	pNova.SetLayoutOptionString2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_AUTHOR, 'Hello World application');
	pNova.SetLayoutOptionString2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_DESCRIPTION, 'overlay position on page');
	
	//anchors
	//percentage or thousands of mm
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_VERTANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_VERTLANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_VERTANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_USE_PERCENT, 0);

	//aspect ratio
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_USE_ASPECT_RATIO, 0);
	//allow stretch with anchors when print on a different page size or layout
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_ALLOW_STRETCH, 0);

	//Rotation (radians)
	pNova.SetLayoutOptionFloat2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_ROTATION, 0);

	//ZIndex (multiple of 5) - objects with higher ZIndex will be above the ones with smaller ZIndex
	pNova.SetLayoutOptionLong2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_ZINDEX, 10);

	//Border
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_USE_BORDER, 1);
	pNova.SetLayoutOptionLong2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_BORDER_POSITION, BORDER_POSITION_INTERIOR);
	pNova.SetLayoutOptionLong2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_BORDER_WIDTH, 2000);
	pNova.SetLayoutOptionLong2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_BORDER_STYLE, BORDER_STYLE_SOLID);
	pNova.SetLayoutOptionLong2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_BORDER_COLOR, RGB(200,120,255));

	//pages
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_FIRSTPAGE, 0);
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_LASTPAGE, 0);
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_ODDPAGE, 0);
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_EVENPAGE, 0);
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_ALLPAGE, 1);
	pNova.SetLayoutOptionBool2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_PAGES, 0);
	pNova.SetLayoutOptionString2(strOverlayId, strLayoutId, NOVAPDF_LAYOUT_PAGERANGE, '1-2');

end;

//------------------------------------------------------------------------------------------//
//-----------------------------------  DIGITAL SIGNATURES  ---------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddSignatureOptions(pNova : INovaPdfOptions90);
var
  strSignatureId, strLayoutId : WideString;
begin
	{
	//choose a certificate : a certificate installed in the system or from a file
	//if you wish to set a system certificate:
	pNova.SetOptionLong(NOVAPDF_SIGN_CERTIFICATE_TYPE, CERTIFICATE_TYPE_SYSTEM);
	//set system signature information so it can be recognized by novaPDF printer
	//this information can be retrieved from system using CertOpenSystemStore, CertEnumCertificatesInStore
	//CertGetNameString - CERT_NAME_SIMPLE_DISPLAY_TYPE, CERT_NAME_SIMPLE_DISPLAY_TYPE
	pNova.SetOptionString2(NOVAPDF_SIGN_SYSCERT_ISSUEDTO, 'C=..., S=..., L=..., O=..., OU=..., E=..., CN=...');
	pNova.SetOptionString2(NOVAPDF_SIGN_SYSCERT_ISSUEDBY, 'C=..., S=..., L=..., O=..., OU=..., E=..., CN=...');
	pNova.SetOptionString2(NOVAPDF_SIGN_SYSCERT_FRIENDLYNAME, '<friendly name>');
	//pCertContext->pCertInfo->Subject
	pNova.SetOptionString2(NOVAPDF_SIGN_SYSCERT_SUBJECT, 'C=..., S=..., L=..., O=..., OU=..., E=..., CN=...');
	pNova.SetOptionString2(NOVAPDF_SIGN_SYSCERT_SUBJECT_NAME, 'subject name');
	pNova.SetOptionString2(NOVAPDF_SIGN_SYSCERT_EXPIRE_DATE, '2013-01-11T20:17:34Z');
	}

	//if you wish to set a certificate from file:
	pNova.SetOptionLong(NOVAPDF_SIGN_CERTIFICATE_TYPE, CERTIFICATE_TYPE_FILE);
	//certificate file and password
	pNova.SetOptionLong(NOVAPDF_SIGN_FILECERT_LOCATION, LOCATION_TYPE_LOCAL);
	pNova.SetOptionString2(NOVAPDF_SIGN_FILECERT_FILE, 'sample.p12');
	//if the file is password protected, enter the password here
	pNova.SetOptionEncryptedString2(NOVAPDF_SIGN_FILECERT_FILE_PASSWORD, 'novapdf');
	//if the folder is on a network path, set network user name and password to access this path
	pNova.SetOptionString2(NOVAPDF_SIGN_FILECERT_USER_NAME, '');
	pNova.SetOptionEncryptedString2(NOVAPDF_SIGN_FILECERT_USER_PASSWORD, '');

	//customize how the signature will look in the PDF file:
	//show or not the Name on the left
	pNova.SetOptionBool(NOVAPDF_SIGN_SHOW_GRAPHIC_NAME, 1);
	//show or not an image on the left
	pNova.SetOptionBool(NOVAPDF_SIGN_SHOW_GRAPHIC_IAMGE, 1);
	//name - opacity percentage
	pNova.SetOptionLong(NOVAPDF_SIGN_NAME_OPACITY, 50);
	//image file
	pNova.SetOptionLong(NOVAPDF_SIGN_IMAGE_LOCATION, LOCATION_TYPE_LOCAL);
	pNova.SetOptionString2(NOVAPDF_SIGN_IMAGE_FILE, 'nopreview.png');
	//if the image file is on a network path, set network user name and password to access this path
	pNova.SetOptionString2(NOVAPDF_SIGN_IMAGE_USER_NAME, '');
	pNova.SetOptionEncryptedString2(NOVAPDF_SIGN_IMAGE_USER_PASSWORD, '');
	//image - keep aspect ratio
	pNova.SetOptionBool(NOVAPDF_SIGN_SHOW_KEEPASPECTRATIO, 1);
	//image - opcaity percentage
	pNova.SetOptionLong(NOVAPDF_SIGN_IMAGE_OPACITY, 50);
	//which details to show on the right
	pNova.SetOptionBool(NOVAPDF_SIGN_SHOW_LABELS, 0);
	pNova.SetOptionBool(NOVAPDF_SIGN_SHOW_CERTIFICATE_NAME, 0);
	pNova.SetOptionBool(NOVAPDF_SIGN_SHOW_SIGN_DATE, 0);
	pNova.SetOptionBool(NOVAPDF_SIGN_SHOW_DETAILS, 1);
	pNova.SetOptionBool(NOVAPDF_SIGN_SHOW_SIGN_LOCATION, 0);
	pNova.SetOptionBool(NOVAPDF_SIGN_SHOW_SIGN_REASON, 0);
	pNova.SetOptionBool(NOVAPDF_SIGN_SHOW_CONTACT_INFO, 0);
	pNova.SetOptionString2(NOVAPDF_SIGN_INFO_REASON, '<myreason>');
	pNova.SetOptionString2(NOVAPDF_SIGN_INFO_LOCATION, '<mylocation>');
	pNova.SetOptionString2(NOVAPDF_SIGN_INFO_CONTACT, '<mycontactinfo>');
	// if you wish a custom font size on the right
	pNova.SetOptionString2(NOVAPDF_SIGN_FONT_NAME, 'Arial');
	pNova.SetOptionLong(NOVAPDF_SIGN_FONT_TYPE, NOVA_FONTTYPE_TRUETYPE);
	pNova.SetOptionBool(NOVAPDF_SIGN_CUSTOM_SIZE, 0);
	pNova.SetOptionLong(NOVAPDF_SIGN_FONT_SIZE, 8);
	// font color
	pNova.SetOptionLong(NOVAPDF_SIGN_NAME_COLOR, RGB(255,0,255));

	//visibility
	pNova.SetOptionBool(NOVAPDF_SIGN_VIEW_VIEW, 1);
	pNova.SetOptionBool(NOVAPDF_SIGN_VIEW_PRINT, 1);
	pNova.SetOptionBool(NOVAPDF_SIGN_VIEW_EXPORT, 1);

	//LAYOUT
	//Get signature ID
	pNova.GetSignature2(strSignatureId, strLayoutId);

	//metadata
	pNova.SetLayoutOptionString2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_NAME, 'Signature Layout');
	pNova.SetLayoutOptionString2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_AUTHOR, 'Hello World application');
	pNova.SetLayoutOptionString2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_DESCRIPTION, 'signature position on page');
	
	//anchors
	//percentage or thousands of mm
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_OFFSET, 10000);
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_VERTANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_VERTLANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_VERTANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_USE_PERCENT, 0);

	//aspect ratio
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_USE_ASPECT_RATIO, 0);
	//allow stretch with anchors when print on a different page size or layout
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_ALLOW_STRETCH, 0);

	// **** COPY NEXT VALUES from novaPDF GUI (profile Layout page, SDK INFO) ****

	//Width / Height
	pNova.SetLayoutOptionFloat2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_OBJECT_WIDTH, 100000);
	pNova.SetLayoutOptionFloat2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_OBJECT_HEIGHT, 50000);

	//rotation
	//Signatures cannot be rotated!! Leave rotation to 0
	pNova.SetLayoutOptionFloat2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_ROTATION, 0);

	//ZIndex (multiple of 5) - objects with higher ZIndex will be above the ones with smaller ZIndex
	pNova.SetLayoutOptionLong2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_ZINDEX, 25);

	//Border
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_USE_BORDER, 1);
	pNova.SetLayoutOptionLong2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_BORDER_POSITION, BORDER_POSITION_EXTERIOR);
	pNova.SetLayoutOptionLong2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_BORDER_WIDTH, 1000);
	pNova.SetLayoutOptionLong2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_BORDER_STYLE, BORDER_STYLE_SOLID);
	pNova.SetLayoutOptionLong2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_BORDER_COLOR, RGB(0,245,0));
	
	//pages
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_FIRSTPAGE, 1);
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_LASTPAGE, 0);
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_ODDPAGE, 0);
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_EVENPAGE, 0);
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_ALLPAGE, 0);
	pNova.SetLayoutOptionBool2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_PAGES, 0);
	pNova.SetLayoutOptionString2(strSignatureId, strLayoutId, NOVAPDF_LAYOUT_PAGERANGE, '');

end;

//------------------------------------------------------------------------------------------//
//-------------------------------------  PAGE CONTENT  -------------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddPageContentOptions(pNova : INovaPdfOptions90);
var
	strContentId, strLayoutId : WideString;
begin
	//LAYOUT
	//Get signature ID
	pNova.GetContentLayout2(strContentId, strLayoutId);

	//metadata
	pNova.SetLayoutOptionString2(strContentId, strLayoutId, NOVAPDF_LAYOUT_NAME, 'Content Layout');
	pNova.SetLayoutOptionString2(strContentId, strLayoutId, NOVAPDF_LAYOUT_AUTHOR, 'Hello World application');
	pNova.SetLayoutOptionString2(strContentId, strLayoutId, NOVAPDF_LAYOUT_DESCRIPTION, 'printed content position on page');
	
	//anchors
	//percentage or thousands of mm
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strContentId, strLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_OFFSET, 15);
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_LEFTANCHOR_USE_PERCENT, 1);

	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strContentId, strLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_OFFSET, 15);
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_RIGHTANCHOR_USE_PERCENT, 1);

	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strContentId, strLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_OFFSET, 15);
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_TOPANCHOR_USE_PERCENT, 1);

	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USED, 1);
	pNova.SetLayoutOptionFloat2(strContentId, strLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_OFFSET, 15);
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_BOTTOMANCHOR_USE_PERCENT, 1);

	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_VERTANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strContentId, strLayoutId, NOVAPDF_LAYOUT_VERTLANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_VERTANCHOR_USE_PERCENT, 0);

	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_USED, 0);
	pNova.SetLayoutOptionFloat2(strContentId, strLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_OFFSET, 0);
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_HORIZANCHOR_USE_PERCENT, 0);

	//aspect ratio
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_USE_ASPECT_RATIO, 0);
	//allow stretch with anchors when print on a different page size or layout
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_ALLOW_STRETCH, 0);

	//Rotation (radians)
	pNova.SetLayoutOptionFloat2(strContentId, strLayoutId, NOVAPDF_LAYOUT_ROTATION, 0);

	//ZIndex (multiple of 5) - objects with higher ZIndex will be above the ones with smaller ZIndex
	pNova.SetLayoutOptionLong2(strContentId, strLayoutId, NOVAPDF_LAYOUT_ZINDEX, -1);

	//Border
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_USE_BORDER, 1);
	pNova.SetLayoutOptionLong2(strContentId, strLayoutId, NOVAPDF_LAYOUT_BORDER_POSITION, BORDER_POSITION_EXTERIOR);
	pNova.SetLayoutOptionLong2(strContentId, strLayoutId, NOVAPDF_LAYOUT_BORDER_WIDTH, 2000);
	pNova.SetLayoutOptionLong2(strContentId, strLayoutId, NOVAPDF_LAYOUT_BORDER_STYLE, BORDER_STYLE_SOLID);
	pNova.SetLayoutOptionLong2(strContentId, strLayoutId, NOVAPDF_LAYOUT_BORDER_COLOR, RGB(200,200,200));

	//pages
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_FIRSTPAGE, 0);
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_LASTPAGE, 0);
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_ODDPAGE, 0);
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_EVENPAGE, 0);
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_ALLPAGE, 1);
	pNova.SetLayoutOptionBool2(strContentId, strLayoutId, NOVAPDF_LAYOUT_PAGES, 0);
	pNova.SetLayoutOptionString2(strContentId, strLayoutId, NOVAPDF_LAYOUT_PAGERANGE, '1-2');

end;

//------------------------------------------------------------------------------------------//
//---------------------------------------  SAVE OPTIONS  -----------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddSaveOptions(pNova : INovaPdfOptions90);
begin
  //choose where to save the pdf file - on the client computer or on the server computer
  pNova.SetOptionLong(NOVAPDF_SAVE_LOCATION, LOCATION_TYPE_LOCAL);

  //what type of save dialog to be shown (none, simple or extended)
  pNova.SetOptionLong(NOVAPDF_SAVE_PROMPT_TYPE, PROMPT_SAVE_NONE);

  //you may choose a predefined folder like "My Documents"
  //pNova.SetOptionLong(NOVAPDF_SAVE_FOLDER_TYPE, SAVEFOLDER_MYDOCUMENTS);

  //or choose a custom folder to save the files
  pNova.SetOptionLong(NOVAPDF_SAVE_FOLDER_TYPE, SAVEFOLDER_CUSTOM);
  pNova.SetOptionString(NOVAPDF_SAVE_FOLDER, 'C:\\temp');

  //if the folder is on a network path, set network user name and password to access this path
  pNova.SetOptionString(NOVAPDF_SAVE_USER_NAME, '');
  pNova.SetOptionEncryptedString(NOVAPDF_SAVE_USER_PASSWORD, '');

  //set a macro for the file name
  pNova.SetOptionString(NOVAPDF_SAVE_FILE_NAME, 'test_[N]');

  //in case a file with the same name exists in the selected folder, choose what to do
  pNova.SetOptionLong(NOVAPDF_SAVE_FILEEXIST_ACTION, FILE_CONFLICT_STRATEGY_OVERWRITE);
end;

//------------------------------------------------------------------------------------------//
//---------------------------------------  MERGE OPTIONS  -----------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddMergeOptions(pNova : INovaPdfOptions90);
begin
	//Enable Merge PDF option
	pNova.SetOptionBool(NOVAPDF_MERGE_ENABLE, 1);
	//show a dialog before printing each document to enter merge options
	pNova.SetOptionBool(NOVAPDF_SHOW_MERGE_DLG, 0);

	//merge file type: 
	//NOVAPDF_MERGE_IF_FILE_EXISTS = TRUE - if a PDF with the same name exists in the Save folder, the new pages will be appended
	//this option is useful when printing multiple documents and wish to add them to the same PDF file
	//NOVAPDF_MERGE_IF_FILE_EXISTS = FALSE - merge with another file specified in NOVAPDF_MERGE_OTHER_FILE option
	//this is useful if for instance you wish to add a title page at the beginning of each PDF you create
	pNova.SetOptionBool(NOVAPDF_MERGE_IF_FILE_EXISTS, 1);

	//if merge with other PDF file (NOVAPDF_MERGE_IF_FILE_EXISTS = FALSE) 
	//choose where is existing PDF file located - on the client computer or on the server computer
	pNova.SetOptionLong(NOVAPDF_MERGE_LOCATION, LOCATION_TYPE_LOCAL);
	
	//Existing PDF for merge
	pNova.SetOptionString(NOVAPDF_MERGE_OTHER_FILE, 'C:\\temp\\title.pdf');

	//if the folder is on a network path, set network user name and password to access this path
	pNova.SetOptionString(NOVAPDF_MERGE_USER, '');
	pNova.SetOptionEncryptedString(NOVAPDF_MERGE_PASSWORD, '');

	//Merge type: append at the end, insert at the beginning or insert at a specified page number
	pNova.SetOptionLong(NOVAPDF_MERGE_TYPE, MERGE_TYPE_APPEND);

	//if merge type is MERGE_TYPE_INSERT_PAGENO set where in the pdf to insert the pages
	pNova.SetOptionLong(NOVAPDF_MERGE_INSERT_PAGENO, 3);

	//in case existing pdf file is password protected, enter the password here
	pNova.SetOptionEncryptedString(NOVAPDF_MERGE_APPEND_PASSWORD, 'my password');
end;

//------------------------------------------------------------------------------------------//
//-----------------------------------------  ACTIONS  --------------------------------------//
//------------------------------------------------------------------------------------------//

procedure AddAction_OpenFile(pNova : INovaPdfOptions90; out strActionID : WideString);
var
  nActionIndex : Integer;
begin
  pNova.AddAction2(NOVA_ACTION_OPEN, 'My Open Action', strActionID, nActionIndex);
  //Execute this action
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_EXECUTE, 1);
  //if action fails, execute the other actions
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_CONTINUE);
  //open original pdf file (the pdf file that was generated now)
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_OPEN_OPENORIGINAL, 1);
  // if NOVAPDF_ACTION_OPEN_OPENORIGINAL is FALSE, open custom file;
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_OPEN_OPENORIGINAL, 0);
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_OPEN_CUSTOMSOURCE, 'C:\temp\<file to open>.pdf');
end;

//------------------------------------------------------------------------------------------//

procedure AddAction_RunApplication(pNova : INovaPdfOptions90; out strActionID : WideString);
var
  nActionIndex : Integer;
begin
  pNova.AddAction2(NOVA_ACTION_RUN, 'My Run Action', strActionID, nActionIndex);
  //Execute this action
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_EXECUTE, 1);
  //if action fails, do not execute the other actions
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_STOP);
  //set application to be run
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_RUN_APPLICATION, 'C:\Program Files (x86)\Adobe\Acrobat Reader DC\Reader\AcroRd32.exe');
  //command line parameters for the application; %1 will be replaced with the generated PDF file name (with full path)
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_RUN_CMDLINE_PARAMETERS, '%1');
  //user and password to connect to the application folder
  //pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_RUN_USER_NAME, 'user');
  //pNova.SetActionOptionEncryptedString2(strActionID, NOVAPDF_ACTION_RUN_USER_PASSWORD, 'password');
  //Show or hide application window
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_RUN_SHOW, RUN_NORMAL);
  //Start tha application as child process or with ShellExecute
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_RUN_SHELL, 1);
end;

//------------------------------------------------------------------------------------------//

procedure AddAction_CopyFile(pNova : INovaPdfOptions90; out strActionID : WideString);
var
  nActionIndex : Integer;
begin
  //add a copy file action before generating pdf (if for instance we wish to append to an existing pdf)
  pNova.AddAction2(NOVA_ACTION_COPY, 'My Copy action', strActionID, nActionIndex);
  //Execute this action
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_EXECUTE, 1);
  //if action fails, do not execute the other actions
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_STOP);
  //copy source: custom file
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_COPY_SOURCECOPYORIGINAL, 0);
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_COPY_CUSTOMSOURCE, '%PROGRAMDATA%\Softland\novaPDF 9\nPdfSdk9_Softland\DefaultFiles\invoice-text.pdf');
  //user and password to connect to pdf file
  //pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_COPY_SOURCEUSERNAME, 'user');
  //pNova.SetActionOptionEncryptedString2(strActionID, NOVAPDF_ACTION_COPY_SOURCEPASSWORD, 'password');
  //copy destination: new created pdf that will be appended
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_COPY_DESTCOPYORIGINAL, 1);
  // if NOVAPDF_ACTION_COPY_DESTCOPYORIGINAL is FALSE, set folder and file name for destination
  //pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_COPY_DESTCOPYORIGINAL, 0);
  //pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_COPY_CUSTOMDESTFOLDER, 'C:\\temp');
  //pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_COPY_CUSTOMDESTFILE, '<my pdf file>.pdf');
  //pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_COPY_DESTKEEPFILENAME, 0);
  //user and password to connect to folder
  //pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_COPY_DESTUSERNAME, 'user');
  //pNova.SetActionOptionEncryptedString2(strActionID, NOVAPDF_ACTION_COPY_DESTPASSWORD, 'password');
end;

//------------------------------------------------------------------------------------------//

procedure AddAction_DeleteFile(pNova : INovaPdfOptions90; out strActionID : WideString);
var
  nActionIndex : Integer;
begin
  pNova.AddAction2(NOVA_ACTION_DELETE, 'My Delete Action', strActionID, nActionIndex);
  //Execute this action
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_EXECUTE, 1);
  //if action fails, execute the other actions
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_CONTINUE);
  //delete original pdf file
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_DELETE_DELETEORIGINAL, 1);
  //if NOVAPDF_ACTION_DELETE_DELETEORIGINAL is TRUS, set the name of file to delete
  //pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_DELETE_DELETEORIGINAL, 0);
  //pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_DELETE_CUSTOMSOURCE, 'C:\\temp\\<file to delete>.pdf');
  //user and password to connect to pdf file
  //pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_DELETE_USERNAME, 'user');
  //pNova.SetActionOptionEncryptedString2(strActionID, NOVAPDF_ACTION_DELETE_PASSWORD, 'password');
end;

//------------------------------------------------------------------------------------------//

procedure AddAction_EmailMAPI(pNova : INovaPdfOptions90; out strActionID : WideString);
var
  nActionIndex : Integer;
begin
  pNova.AddAction2(NOVA_ACTION_EMAILMAPI, 'My Email MAPI Action', strActionID, nActionIndex);
  //Execute this action
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_EXECUTE, 1);
  //if action fails, execute the other actions
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_CONTINUE);
  //Show dialog before printing each document to enter email address
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SHOW_DIALOG, 0);
  //Email MAPI method (show dialog or send automatically)
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_EMAILMAPI_SENDEMAIL, EMAIL_TYPE_MAPI_DLG);
  //Email details
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILMAPI_SUBJECT, 'my email subject');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILMAPI_BODY, 'my email body');
  //flag if the addresses should be looked up in the address book
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_EMAILMAPI_LOOKUP_ADDRESS, 0);
  //flag - if the PDF should be sent as zip compression
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_EMAILMAPI_COMPRESS, 0);
  //flag - change the extension for the compressed zip attachment
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_EMAILMAPI_CHANGEEXTENSION, 0);
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILMAPI_EXTENSION, 'txt');
  //attach the PDF to the email
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_EMAILMAPI_ATTACH_PDF, 1);
  //attach other file to the email
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_EMAILMAPI_ATTACH_OTHER_FILES, 0);
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILMAPI_OTHER_FILES, 'path to other files to attach');
  //Set receipient addresses
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILMAPI_FROM, 'from_adress');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILMAPI_TO, 'to_adress');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILMAPI_CC, 'cc_adress');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILMAPI_BCC, 'bcc_adress');
end;

//------------------------------------------------------------------------------------------//

procedure AddAction_EmailSMTP(pNova : INovaPdfOptions90; out strActionID : WideString);
var
  nActionIndex : Integer;
begin
  pNova.AddAction2(NOVA_ACTION_EMAILSMTP, 'My Email SMTP Action', strActionID, nActionIndex);
  //Execute this action
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_EXECUTE, 1);
  //if action fails, execute the other actions
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_CONTINUE);
  //Show dialog before printing each document to enter email address
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SHOW_DIALOG, 0);
  //SMTP server name and port
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILSMTP_SERVER, 'my SMTP server name');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILSMTP_PORT, '25');
  //SMTP account
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILSMTP_ACCOUNT, 'my SMTP user name');
  pNova.SetActionOptionEncryptedString2(strActionID, NOVAPDF_EMAILSMTP_PASSWORD, 'my SMTP password');
  //flags, if the SMTP server requires Authentification or SSL (1 or 0)
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_EMAILSMTP_SSL, 0);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_EMAILSMTP_TLS, 0);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_EMAILSMTP_AUTHENTICATION, 0);
  //Email details
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILSMTP_SUBJECT, 'my email subject');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILSMTP_BODY, 'my email body');
  //flag - if the PDF should be sent as zip compression
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_EMAILSMTP_COMPRESS, 0);
  //flag - change the extension for the compressed zip attachment
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_EMAILSMTP_CHANGEEXTENSION, 0);
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILSMTP_EXTENSION, 'txt');
  //attach the PDF to the email
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_EMAILSMTP_ATTACH_PDF, 1);
  //attach other file to the email
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_EMAILSMTP_ATTACH_OTHER_FILES, 0);
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILSMTP_OTHER_FILES, 'path to other files to attach');
  //Set receipient addresses
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILSMTP_FROM, 'from adress');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILSMTP_TO, 'to adress');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILSMTP_CC, 'cc adress');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_EMAILSMTP_BCC, 'bcc adress');
end;

//------------------------------------------------------------------------------------------//

procedure AddAction_FTP(pNova : INovaPdfOptions90; out strActionID : WideString);
var
  nActionIndex : Integer;
begin
  pNova.AddAction2(NOVA_ACTION_FTP, 'My FTP Action', strActionID, nActionIndex);
  //Execute this action
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_EXECUTE, 1);
  //if action fails, execute the other actions
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_CONTINUE);
  //original pdf file
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_FTP_SOURCEORIGINAL, 1);
  // if NOVAPDF_ACTION_FTP_SOURCEORIGINAL is FALSE, set the name of file to upload
  //pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_FTP_SOURCEORIGINAL, 0);
  //Nova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_FTP_SOURCEFILE, 'C:\\temp\\<file to upload>');
  //user and password to connect to source pdf file
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_FTP_SOURCEUSER, 'user');
  pNova.SetActionOptionEncryptedString2(strActionID, NOVAPDF_ACTION_FTP_SOURCEPASSWORD, 'password');
  //destination folder
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_FTP_DESTFOLDER, 'test');
  //use the same file name
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_FTP_KEEPFILENAME, 1);
  //or change file name
  //pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_FTP_KEEPFILENAME, 0);
  //pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_FTP_DESTFILE, '<new file name>');
  //ftp server
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_FTP_SERVER, '192.168.1.1');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_FTP_PORT, '21');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_FTP_USERNAME, 'user');
  pNova.SetActionOptionEncryptedString2(strActionID, NOVAPDF_ACTION_FTP_PASSWORD, 'password');
  //host
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_FTP_HOST, '');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_FTP_HOSTPORT, '80');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_FTP_HOSTUSERNAME, '');
  pNova.SetActionOptionEncryptedString2(strActionID, NOVAPDF_ACTION_FTP_HOSTPASSWORD, '');
  //ftp options
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_FTP_UPLOADSPEEDCHECK, 0);
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_FTP_UPLOADSPEED, 200);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_FTP_USEPASSIVEMODE, 0);
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_FTP_TIMEOUT, 30);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_FTP_RETRY, 0);
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_FTP_RETRYVALUE, 2);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_FTP_WAIT, 0);
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_FTP_WAITVALUE, 60);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_FTP_SSL, 0);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_FTP_USEPROXY, 0);
end;

//------------------------------------------------------------------------------------------//

procedure AddAction_SFTP(pNova : INovaPdfOptions90; out strActionID : WideString);
var
  nActionIndex : Integer;
begin
  pNova.AddAction2(NOVA_ACTION_SFTP, 'My SFTP Action', strActionID, nActionIndex);
  //Execute this action
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_EXECUTE, 1);
  //if action fails, execute the other actions
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_FAIL, NOVA_ACTION_FAIL_CONTINUE);
  //upload original pdf file
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_SOURCEORIGINAL, 1);
  //or upload a custom file
  //pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_SOURCEORIGINAL, 0);
  //pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_SFTP_SOURCEFILE, 'C:\\temp\\<custom file>');
  //user and password to connect to source pdf file
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_SFTP_SOURCEUSER, '');
  pNova.SetActionOptionEncryptedString2(strActionID, NOVAPDF_ACTION_SFTP_SOURCEPASSWORD, '');
  //destination folder
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_SFTP_DESTFOLDER, 'test');
  // destination file name - use the same file name
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_KEEPFILENAME, 1);
  // or change file name
  //pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_KEEPFILENAME, 0);
  //pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_SFTP_DESTFILE, '<new file name>');
  //sftp server
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_SFTP_SERVER, '192.168.1.1');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_SFTP_PORT, '22');
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_SFTP_USERNAME, 'user');
  pNova.SetActionOptionEncryptedString2(strActionID, NOVAPDF_ACTION_SFTP_PASSWORD, 'password');
  //sftp options
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_USEPRIVATEKEY, 0);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_UPLOADSPEEDCHECK, 0);
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_SFTP_UPLOADSPEED, 200);
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_SFTP_TIMEOUT, 30);
  pNova.SetActionOptionString2(strActionID, NOVAPDF_ACTION_SFTP_KEYFILENAME, '');
  pNova.SetActionOptionEncryptedString2(strActionID, NOVAPDF_ACTION_SFTP_KEYFILEPASSWORD, '');
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_RETRY, 0);
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_SFTP_RETRYVALUE, 2);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_WAIT, 0);
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_SFTP_WAITVALUE, 30);
  //Authentications
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_AUTH_PUBLICKEY, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_AUTH_PASSWORD, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_AUTH_KEYBOARDINT, 1);
  //Ciphers
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_AES256CTR, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_3DESCBC, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_AES128CBC, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_AES192CBC, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_AES256CBC, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_BLOWFISHCBC, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_TWOFISHCBC, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_TWOFISH192CBC, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_TWOFISH128CBC, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_TWOFISH256CBC, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_ARCFOUR, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_ARCFOUR128, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_ARCFOUR256, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_CAST128CBC, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_AES128CTR, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_CIPHER_AES192CTR, 1);
  //MACs
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_MAC_MD5, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_MAC_SHA1, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_MAC_SHA2256, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_MAC_SHA225696, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_MAC_RIPEMD160, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_MAC_RIPEMD160OPENSSH, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_MAC_MD596, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_MAC_SHA196, 1);
  //Compression
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_COMPRESS_NONE, 1);
  pNova.SetActionOptionBool2(strActionID, NOVAPDF_ACTION_SFTP_COMPRESS_ZLIBOPENSSH, 1);
end;

//------------------------------------------------------------------------------------------//
//------------------------------------------------------------------------------------------//

procedure DeleteActionType(pNova : INovaPdfOptions90; nActionType : Integer);
var
  strActionID : WideString;
  nCount, n, nType : Integer;
begin
  pNova.GetActionCount(nCount);
  n := nCount - 1;
  //parse actions
  while n >= 0 do
  begin
    pNova.GetAction2(n, strActionID, nType);
    //delete all actions of given type
    if nType = nActionType then
    begin
      pNova.DeleteAction2(strActionID);
    end;
    n := n-1;
  end;
end;

//------------------------------------------------------------------------------------------//
// There can be added actions to manipulate files (copy or delete), to run applications (open or run),
//   to send the pdf by email (MAPI or SMTP) or to upload the pdf (with FTP or SFTP)
// Next there is an exemple of actions that append the new generated pdf to an existing one,
//  send it by email and then deletes the pdf. There are used next actions
// - a copy action that copies the original pdf that must be appended; this action will be performed before generating the pdf
// - an email MAPI action
// - a delete action
//------------------------------------------------------------------------------------------//

procedure AddActionsOptions(pNova : INovaPdfOptions90);
var
  strActionID : WideString;
begin
  //DO NOT OPEN PDF
  //an Open action is added by default in the profile - delete or disable this open action
  pNova.DisableActionType(NOVA_ACTION_OPEN);
  //add action copy; will copy the file that will be appended
  AddAction_CopyFile(pNova, strActionID);
  //set action index to 1 - first in the actions list - so it is executed before generate pdf
  pNova.SetActionOptionLong2(strActionID, NOVAPDF_ACTION_INDEX, 0);
  //modify save options to append to existing pdf
  AddSaveOptions(pNova);
  //add action email MAPI - open default rmail client send email window
  AddAction_EmailMAPI(pNova, strActionID);
  //add action delete - delete created pdf file
  AddAction_DeleteFile(pNova, strActionID);
  //add action run application
  //AddAction_RunApplication(pNova, strActionID);
  //add action open file
  //AddAction_OpenFile(pNova, strActionID);
  //add action email SMTP
  //AddAction_EmailSMTP(pNova, strActionID);
  //add action FTP
  //AddAction_FTP(pNova, strActionID);
  //add action SFTP
  //AddAction_SFTP(pNova, strActionID);
end;

end.
